#include<iostream>
#include "param.h"
#include<vector>
#include "qdir.h"
#include "qstring.h"
#include "qfileinfo.h"
#include "Dal.h"
#include"errstr.h"
/***************************************************************
*
*
*
* NB decZ is the mean DEC pointing direction (radians)
****************************************************************/
extern "C" void checkimagefiles_(float *raOffset, float *decOffset, double *decZ)
{


    errstr << "Checking astrometry corrections in mosaiced image-files"
           << Sas::message(Msg::App, Msg::Sparse);

    
    vector<string> srcList = stringListParameter("sourcelistsets");


    //    for(unsigned i = 0; i < srcList.size(); i++)
    // {
    //  cout << i << ") " << srcList[i] << endl;

    // }


    /***************************************************
    *
    *
    ****************************************************/
    
    size_t k = srcList[0].rfind('/');

   
    string directory;
    if(k == string::npos)  // Not found
    {
      directory = "";
    }
    else
    {
     
      directory = srcList[0].substr(0, k + 1);
    }



    QDir thisDir( directory );
    if ( !thisDir.isReadable() ) 
    {
        return;
    }

       
    const QFileInfoList * files = thisDir.entryInfoList();
    if ( files ) 
    {
        QFileInfoListIterator it( *files );
        QFileInfo * fi;
        while( (fi = it.current()) != 0 ) 
        {
            ++it;
            QString file = directory + fi->fileName();

            /************************************************************
	    *
            *
            *
            *
            ************************************************************/
            if ( file.contains("IMAGU") || file.contains("IMAGB")  ||
                 file.contains("IMAGV") || file.contains("IMAGW")  ||
                 file.contains("IMAGL") || file.contains("IMAGM")  ||
                 file.contains("IMAGS") )       
            {
	                    
                // Open the file
                DataSet *dataSet = dataSetServer->open(file, Dal::Modify);
                if (!dataSet)
	        {


                }
              
                if(dataSet->hasAttribute("POSCOROK") )
	        {
	            bool posCorrOkay = dataSet->attribute("POSCOROK")->asBool();

                    if (!posCorrOkay) // No astrometry correction applied to image
		    {	   
		        errstr << "Adding mean offsets " << *raOffset << " and " << *decOffset << " to " << file 
                               << Sas::message(Msg::App, Msg::Sparse);

	                          
                        *dataSet->addAttribute( "POSCOROK", "Images were astrometry corrected") = true;
                        *dataSet->addAttribute( "RAOFFSET", "Mean RA offset applied to images") = *raOffset;
                        *dataSet->addAttribute( "DEOFFSET", "Mean DEC offset applied to images") = *decOffset;

                        /******************************************************************
		        *
                        * Need to correct CRVAL1 and CRVAL2 values
                        *
                        *******************************************************************/
                        double crval1 = dataSet->attribute("CRVAL1")->asReal();          
                        double crval2 = dataSet->attribute("CRVAL2")->asReal();

                        double cs = cos(*decZ);          
                        *dataSet->addAttribute( "CRVAL1", "RA offset applied to image from omsrclistcomb") =  crval1 + *raOffset / (3600.0 * cs);
                        *dataSet->addAttribute( "CRVAL2", "DEC offset applied to image from omsrclistcomb") =  crval2 + *decOffset / 3600.0;
                    }

                } 

                dataSetServer->close(dataSet); // Finished with the file

            }
        }
       
    }


}

